// Copyright 2000-2005 the Contributors, as shown in the revision logs.
// Licensed under the Apache Public Source License 2.0 ("the License").
// You may not use this file except in compliance with the License.

package org.ibex.util;
import java.util.*;
import java.net.*;
import java.io.*;

/** run cycle() repeatedly, no more often than minCycleTimeMillis; catch and log any exceptions. */
public abstract class ImmortalThread extends Thread {
    
    private final int minCycleTimeMillis;
    public ImmortalThread() { this(500); }
    public ImmortalThread(int minCycleTimeMillis) { this.minCycleTimeMillis = minCycleTimeMillis; }
    
    public abstract void cycle() throws Exception;

    public final void run() {
        while(true) {
            long now = System.currentTimeMillis();
            try {
                cycle();
            } catch (Exception e) { Log.warn(this, e); }
            long now2 = System.currentTimeMillis();
            if (now2 - now < minCycleTimeMillis)
                try { Thread.sleep(minCycleTimeMillis - (now2 - now)); } catch (Exception e) { }
        }
    }

}
